@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::2_0::Direct::Cat;
-$Search::Elasticsearch::Client::2_0::Direct::Cat::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::2_0::Direct::Cat::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::2_0::Direct::Cat::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
@@ -28,7 +29,7 @@ Search::Elasticsearch::Client::2_0::Direct::Cat - A client for running cat debug
 
 =head1 VERSION
 
-version 6.80
+version 6.80_01
 
 =head1 DESCRIPTION
 
