@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::2_0::Scroll;
-$Search::Elasticsearch::Client::2_0::Scroll::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::2_0::Scroll::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::2_0::Scroll::VERSION = '6.8001';use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
 
@@ -126,7 +127,7 @@ Search::Elasticsearch::Client::2_0::Scroll - A helper module for scrolled search
 
 =head1 VERSION
 
-version 6.80
+version 6.80_01
 
 =head1 SYNOPSIS
 
